<?php
/**
 *  Includes all styles and scripts for ArtistPress admin functionality.
 *
 *  @author     LTDI Studios
 *  @package    ArtistPress/includes
 *  @version    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}



/**
 * Enqueues the script and style based on what admin page you are looking at.
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 * @global $pagenow Used to determine what page we are one.
 * @global $typenow Used to determine what post type we are one.
 *
 */
function  artistpress_enqueue_admin_script(){
    
    /**
    *   
    *   These too global variable will tell us what file ($pagenow) we are using and
    *   what post type ($typenow) we are using.
    *
    */
    global $pagenow, $typenow;
    
    
    /**
    *   
    *   Using the global variables verify post edit screen and post type then
    *   include proper styles based on what post type ($typenow) we are using.
    *
    */
    if (($pagenow == 'post.php' || $pagenow == 'post-new.php')){

        wp_enqueue_style( 'artist-press-post-admin', plugins_url('/css/admin-posttype.css', __FILE__ ) );
        wp_enqueue_style( 'artist-press-admin-theme', plugins_url('/css/jquery-ui.css', __FILE__ ) );
        wp_enqueue_style( 'artist-press-admin-theme-2', plugins_url('/css/jquery-ui.theme.min.css', __FILE__ ) );
        //wp_enqueue_script('artist-press-post-admin', plugins_url('/js/artist-press-admin.js', __FILE__ ), array('jquery', 'jquery-ui-datepicker'), '', true);

    }
    if ($typenow == 'venue'){

        $artistpress_map_settings = get_option('artistpress_show_settings');
        $apikey = $artistpress_map_settings['artistpress_maps_api'];

        if ( ! empty( $apikey ) ) {
            $mapsapi = '//maps.googleapis.com/maps/api/js?key=' . $apikey;
            wp_register_script( 'googlemaps', $mapsapi ,'','', true);
            wp_register_script( 'artistpress_geocode_js', plugins_url( '/js/address-geocoder.js', __FILE__ ) ,'','', true );

            wp_enqueue_script( 'googlemaps' );
            wp_enqueue_script( 'artistpress_geocode_js' );
        }
    }
    if ($pagenow == 'admin.php'){
        wp_enqueue_style( 'artist-press-post-admin', plugins_url('/css/admin-dashboard.css', __FILE__ ) );
        wp_enqueue_style( 'artist-press-post-icon-fonts', plugins_url('/css/font-awesome.min.css', __FILE__ ) );
    }

}
add_action('admin_enqueue_scripts','artistpress_enqueue_admin_script');