<?php

namespace ArtistPress_Utilities;

/**
*   
*   Exit if accessed directly
*
*/	
if( !defined('ABSPATH')){
	exit;
}



class Upgrader_1_2_2 extends Upgrader
{

    const SHOW_ARTIST           =   'artistpress_show_artist';
    const SHOW_ARTIST_NAME      =   'artistpress_show_artist_name';
    const SHOW_VENUE            =   'artistpress_show_venue';
    const SHOW_VENUE_NAME       =   'artistpress_show_venue_name';


    /**
	 * Get array of show IDs
     * 
	 * @access 	private
	 * @return 	array $shows
	 */
    private function get_shows()
    {
        $args = array( 
            'post_type' => 'show',
            'numberposts' => -1,
            'post_status' => 'publish',
            'fields' => 'ids',
        );
        return apply_filters( __METHOD__ , get_posts($args) );
    }
    
    
    /**
	 * Get the show Artist ID
     * 
	 * @access 	private
     * @param   int $show_id
	 * @return 	int $artist_id
     * 
	 */
    private function get_artist_id( $show_id )
    {
        $artist_id = get_post_meta( $show_id , self::SHOW_ARTIST , true)[0] ?: null;
        return apply_filters( __METHOD__ , $artist_id  ); 
    }
    
    
    /**
	 * Get the show Venue ID
     * 
	 * @access 	private
     * @param   int $show_id
	 * @return 	int $venue_id
     * 
	 */
    private function get_venue_id( $show_id )
    {
        $venue_id = get_post_meta( $show_id , self::SHOW_VENUE , true)[0] ?: null;
        return apply_filters( __METHOD__ , $venue_id  ); 
    }
    
    
    /**
	 * Get the show Artist Name
     * 
	 * @access 	private
     * @param   int     $show_id
	 * @return 	string  $show_artist_name
     * 
	 */
    private function get_artist_name( $show_id )
    {
        if (( in_array( self::SHOW_ARTIST_NAME , get_post_custom_keys( $show_id ) ) )){
            return add_filter( __METHOD__ , '__return_empty_string' );
        }

        $show_artist_name = get_post_field( 'post_name' , $this->get_artist_id( $show_id ) ) ;
        
        return apply_filters( __METHOD__ , $show_artist_name ); 
    }
    
    
    /**
	 * Get the show Venue Name
     * 
	 * @access 	private
     * @param   int     $show_id
	 * @return 	string  $show_venue_name
     * 
	 */
    private function get_venue_name( $show_id )
    {
        if ( ( in_array( self::SHOW_VENUE_NAME , get_post_custom_keys( $show_id ) ) ) ){
            return add_filter( __METHOD__ , '__return_empty_string' );
        }
        
        $show_venue_name = get_post_field( 'post_name' , $this->get_venue_id( $show_id ) ) ;
        
        return apply_filters( __METHOD__ ,  $show_venue_name ); 
    }
    
    
    /**
	 * Set the show Artist Name
     * 
	 * @access 	private
     * @param   int     $show_id
     * @param   string  $artist_name
	 * @return 	void
     * 
	 */
    private function set_artist_name( $show_id , $artist_name)
    {
        update_post_meta( $show_id , self::SHOW_ARTIST_NAME, $artist_name );
    }
    
    
    /**
	 * Set the show Venue Name
     * 
	 * @access 	private
     * @param   int     $show_id
     * @param   string  $venue_name
	 * @return 	void
     * 
	 */
    private function set_venue_name( $show_id , $venue_name )
    {
        update_post_meta( $show_id , self::SHOW_VENUE_NAME, $venue_name );
    }
    
    
    /**
	 * Runs the upgrade
	 * @access 	private
	 * @return 	string $address
     * 
	 */ 
    public function run_upgrade()
    {
        foreach( $this->get_shows() as $show ){
            $this->set_artist_name( $show , $this->get_artist_name( $show ) );
            $this->set_venue_name( $show , $this->get_venue_name( $show ) );
        }
        update_site_option( 'artistpress_version' , $this->version );
    }

}
