<?php

/**
 * Builds the ArtistPress Setings Page
 *
 *  @author     LTDI Studios
 *  @package    ArtistPress/views
 *  @version    1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}



/**
 * Initializes the ArtistPress settings tabs
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_initialize_settings( $active_tab = null ){ ?>

    <!-- Create a header in the default WordPress 'wrap' container -->
    <div class="wrap">
    <div id="icon-themes" class="icon32"></div>
    
    <h2>ArtistPress Settings:</h2>
    <?php settings_errors(); ?>
    
    
    <?php
    if( isset( $_GET[ 'tab' ] ) ) {
         $active_tab = $_GET[ 'tab' ];
    
    } else if( $active_tab == 'artist_settings' ) {
        $active_tab = 'artist_settings';

    } else if( $active_tab == 'show_list_settings' ) {
        $active_tab = 'show_list_settings';

    } else if( $active_tab == 'show_settings' ) {
        $active_tab = 'show_settings';

    } else if( $active_tab == 'playlist_settings' ) {
        $active_tab = 'playlist_settings';
    
    }else if( $active_tab == 'gallery_settings' ) {
        $active_tab = 'gallery_settings';

    } else if( $active_tab == 'license_settings' ) {
        $active_tab = 'license_settings';

    } else if( $active_tab == 'input_examples' ) {
        $active_tab = 'input_examples';
    
    } else {
        $active_tab = 'artistpress_settings';
    
    }
    ?>
    
    <h2 class="nav-tab-wrapper">
    <a href="?page=artistpress-settings&tab=artistpress_settings" class="nav-tab <?php echo $active_tab == 'artistpress_settings' ? 'nav-tab-active' : ''; ?>">Artist Settings</a>
    <a href="?page=artistpress-settings&tab=show_list_settings" class="nav-tab <?php echo $active_tab == 'show_list_settings' ? 'nav-tab-active' : ''; ?>">Show List Settings</a>
    <a href="?page=artistpress-settings&tab=show_settings" class="nav-tab <?php echo $active_tab == 'show_settings' ? 'nav-tab-active' : ''; ?>">Individual Show Settings</a>
    <a href="?page=artistpress-settings&tab=gallery_settings" class="nav-tab <?php echo $active_tab == 'gallery_settings' ? 'nav-tab-active' : ''; ?>">Gallery Settings</a>
    <a href="?page=artistpress-settings&tab=upgrade" class="nav-tab <?php echo $active_tab == 'upgrade' ? 'nav-tab-active' : ''; ?>">Upgrade</a>
    </h2>
    
    
    <form method="post" action="options.php">
    
    <?php   if ($active_tab == 'artistpress_settings'){
                settings_fields( 'artistpress_artist_settings' ); 
                do_settings_sections( 'artistpress_artist_settings' ); 
                submit_button();
            
            }elseif ($active_tab == 'show_list_settings'){
                settings_fields( 'artistpress_show_list_settings' ); 
                do_settings_sections( 'artistpress_show_list_settings' ); 
                submit_button();

            }elseif ($active_tab == 'show_settings'){
                settings_fields( 'artistpress_show_settings' ); 
                do_settings_sections( 'artistpress_show_settings' );
                submit_button(); 

            }elseif ($active_tab == 'gallery_settings'){
                settings_fields( 'artistpress_gallery_settings' ); 
                do_settings_sections( 'artistpress_gallery_settings' );
                submit_button(); 

            }elseif ($active_tab == 'upgrade'){
                settings_fields( 'artistpress_upgrade_settings' ); 
                do_settings_sections( 'artistpress_upgrade_settings' ); 
        
            }else{
                settings_fields( 'artistpress_artist_settings' ); 
                do_settings_sections( 'artistpress_artist_settings' );
                submit_button();  
            }
        ?>
    </form>
    </div>

<?php }




/**
 * Registers the ArtistPress Artist settings
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_register_artist_settings(){
    
    // If the Artistpress artist options do not exist, create them using these defaults.
    if( false == get_option( 'artistpress_artist_settings' ) ) { 
        $defaults = array(
            'artist_name'                   => 'yes',
            'artist_phone'                  => 'yes',
            'artist_phone_link'             => 'no',
            'artist_email'                  => 'yes',
            'artist_web'                    => 'yes',
            'artist_bio'                    => 'yes',
            'artist_use_artist_stylesheet'  => 'yes',
            'artist_use_artist_shortcode'   => 'yes'
        );
        add_option( 'artistpress_artist_settings', $defaults);
    }

    // Adds the Artist settings section.
    add_settings_section(
        'artistpress_artist_settings_section',
        'Artist Settings',
        'artistpress_artist_settings_callback',
        'artistpress_artist_settings'      
    );

    // Adds setting field to the Artist settings section.
    add_settings_field(
        'artist_name',
        'Artist Name',
        'artistpress_artist_name_callback',
        'artistpress_artist_settings', 
        'artistpress_artist_settings_section',
        array(
            'Should the artist\'s name be displayed on the artist pages?'
        )
    );

    // Adds setting field to the Artist settings section.
    add_settings_field(
        'artist_phone',
        'Phone Number',
        'artistpress_artist_phone_callback',
        'artistpress_artist_settings', 
        'artistpress_artist_settings_section',
        array(
            'Should the artist\'s phone number be displayed on the artist pages?'
        )
    );

    // Adds setting field to the Artist settings section.
    add_settings_field(
        'artist_phone_link',
        'Link Phone Number',
        'artistpress_artist_phoneLink_callback',
        'artistpress_artist_settings', 
        'artistpress_artist_settings_section',
        array(
            'Should the artist\'s phone number be click-to-dial functionality?'
        )
    );

    // Adds setting field to the Artist settings section.
    add_settings_field(
        'artist_email',
        'Show Email',
        'artistpress_artist_email_callback',
        'artistpress_artist_settings', 
        'artistpress_artist_settings_section',
        array(
            'Should the artist\'s email be displayed on the artist pages?'
        )
    );

    // Adds setting field to the Artist settings section.
    add_settings_field(
        'artist_web',
        'Show Website',
        'artistpress_artist_web_callback',
        'artistpress_artist_settings', 
        'artistpress_artist_settings_section',
        array(
            'Should the artist\'s website be displayed on the artist pages?'
        )
    );

    // Adds setting field to the Artist settings section.
    add_settings_field(
        'artist_bio',
        'Show Bio',
        'artistpress_artist_bio_callback',
        'artistpress_artist_settings', 
        'artistpress_artist_settings_section',
        array(
            'Should the artist\'s bio be displayed on the artist pages?'
        )
    );

    // Adds setting field to the Artist settings section.
    add_settings_field( 
        'artist_use_stylesheet',
        'Artist Default Stylesheet',
        'artistpress_artist_stylesheet_callback',
        'artistpress_artist_settings', 
        'artistpress_artist_settings_section',
        array(
            'Should the default artist stylesheet be used to display the galleries?'
        )
    );

    // Adds setting field to the Artist settings section.
    add_settings_field( 
        'artist_use_shortcode',
        'Use Templates for Artists',
        'artistpress_artist_shortcode_callback',
        'artistpress_artist_settings', 
        'artistpress_artist_settings_section',
        array(
            'Use WordPress templates instead of shortcodes (recommended for developer use only).'
        )
    );
    
    // Registers the Artist settings section.
    register_setting(
        'artistpress_artist_settings',
        'artistpress_artist_settings',
        'artistpress_validate_input_examples'
    );

}
add_action('admin_init', 'artistpress_register_artist_settings');






/**
 * Registers the ArtistPress Show settings
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_register_show_list_settings(){
    
    // If the Artistpress Show options do not exist, create them using these defaults.
    if( false == get_option( 'artistpress_show_list_settings' ) ) {  
        $defaults = array(
            'show_list_display'         => 'show_date',
            'display_show_artist'       => 'yes',
            'show_list_order'           =>'ASC',
            'display_show_venue'        => 'yes',
            'display_ticket_button'     => 'yes',
            'show_ticket_button_label'  => NULL,
            'display_info_button'       => 'yes',
            'show_info_button_label'    => NULL,
            'show_list_use_stylesheet'  => 'yes',
            'show_list_use_shortcode'   => 'yes',
        );
        add_option( 'artistpress_show_list_settings', $defaults);
    }
    
    // Adds the Show List settings section.
    add_settings_section(
        'artistpress_show_list_settings_section', 
        'Show List Settings',                      
        'artistpress_show_list_settings_callback',      
        'artistpress_show_list_settings'              
    );
    
    // Adds a settings field to Show List settings section.
    add_settings_field( 
        'show_list_display',
        'Show List Display',
        'artistpress_show_list_display_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Choose how your ArtistPress show listing is displayed.'
        )
    );

    // Adds a settings field to Show List settings section.
    add_settings_field( 
        'show_list_order',
        'Show List Order',
        'artistpress_show_list_display_order',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Choose the order of your ArtistPress show list. Ascending (Z-A or 100-1 ) or Descending (A-Z or 1-100 ). Ascending is the default.',
        )
    );

    // Adds a settings field to Show List settings section.
    add_settings_field( 
        'display_show_artist',
        'Artist Name',
        'artistpress_show_list_artist_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Should the artist\'s name be displayed on the show list. (If displayed by by Artist this setting has no effect on the list.)'
        )
    );

    // Adds a setting field to Show List settings section.
    add_settings_field( 
        'display_show_venue',
        'Venue Name',
        'artistpress_show_list_venue_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Should the venue name be displayed on the show list. (If displayed by Venue this setting has no effect on the list.)'
        )
    );

    // Adds a setting field to Show List settings section.
    add_settings_field( 
        'display_ticket_button',
        'Ticket Button',
        'artistpress_show_list_ticket_link_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Should there be a button to get tickets on the show list.'
        )
    );

    // Adds a setting field to Show List settings section.
    add_settings_field( 
        'show_ticket_button_label',
        'Ticket Button Label',
        'artistpress_show_list_ticket_link_label_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Enter the words you want to appear on the ticket button. Defaults to "Get Tickets".'
        )
    );

    // Adds a setting field to Show List settings section.
    add_settings_field( 
        'display_info_button',
        'More Info Button',
        'artistpress_show_list_info_link_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Should there be a button to get more info about the shows on the show list.'
        )
    );

    // Adds a setting field to Show List settings section.
    add_settings_field( 
        'show_info_button_label',
        'More Info Button Label',
        'artistpress_show_list_info_link_label_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Enter the words you want to appear on the more info button. Defaults to "Additional Info".'
        )
    );  

    // Adds a setting field to Show List settings section.
    add_settings_field( 
        'show_list_use_stylesheet',
        'Calendar Default Stylesheet',
        'artistpress_show_list_stylesheet_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Should the default calendar stylesheet be used to display the shows?'
        )
    );

    // Adds a setting field to Show List settings section.
    add_settings_field( 
        'show_list_use_shortcode',
        'Use Templates for Shows',
        'artistpress_show_list_shortcode_callback',
        'artistpress_show_list_settings',
        'artistpress_show_list_settings_section',
        array(
            'Use WordPress templates instead of shortcodes (recommended for developer use only). You will need to flush the permalinks <a href="'. get_bloginfo('url').'/wp-admin/options-permalink.php">here</a> after changing this setting.'
        )
    );

    // Registers the Show List settings section.
    register_setting(
        'artistpress_show_list_settings',
        'artistpress_show_list_settings',
        'artistpress_validate_input_examples'
    );
}
add_action('admin_init', 'artistpress_register_show_list_settings');





/**
 * Registers the ArtistPress Individual Show settings
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_register_show_settings(){
    
    // If the Artistpress Individual Show options do not exist, create them using these defaults.
    if( false == get_option( 'artistpress_show_settings' ) ) {  
        $defaults = array(
             'display_show_artwork'          => 'yes',
             'display_show_date'             => 'yes',
             'display_show_time'             => 'yes',
             'display_show_type'             => 'yes',
             'display_show_price'            => 'yes',
             'display_ticket_phone'          => 'yes',
             'display_ticket_button'         => 'yes',
             'display_additional_info'       => 'yes',
             'display_venue'                 => 'yes',
             'display_venue_address'         => 'yes',
             'display_venue_phone'           => 'yes',
             'display_venue_website_button'  => 'yes',
             'map_display'                   => 'no',
             'map_directions'                => 'no',
             'artistpress_maps_api'          => null,
             'show_use_stylesheet'           => 'yes',
             'show_use_shortcode'            => 'no'
         );
        add_option( 'artistpress_show_settings', $defaults );
    }
    
    // Adds the Individual Shows settings section.
    add_settings_section(
        'artistpress_show_settings_section',
        'Individual Shows Settings',
        'artistpress_show_settings_callback',
        'artistpress_show_settings'
    );
    
    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_show_artwork',
        'Display Show Artwork',
        'artistpress_display_show_artwork_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the show artwork be shown on the individual show page.'
        )
    );
    
    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_show_date',
        'Display Show Date',
        'artistpress_display_show_date_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the date of the show be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_show_time',
        'Display Show Time',
        'artistpress_display_show_time_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the show time be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_show_type',
        'Display Show Type',
        'artistpress_display_show_type_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the show type be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_show_price',
        'Display Show Price',
        'artistpress_display_show_price_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the show price be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_ticket_phone',
        'Ticket Phone Number',
        'artistpress_display_ticket_phone_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should a phone number to get tickets be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'calendar_ticket_button',
        'Ticket Button',
        'artistpress_show_ticket_link_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should there be a button to get tickets displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_additional_info',
        'Additional Info',
        'artistpress_show_additional_info_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the additional information section be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.    
    add_settings_field( 
        'display_venue',
        'Display Venue',
        'artistpress_display_venue_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the venue details section be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_venue_address',
        'Display Venue Address',
        'artistpress_display_venue_address_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the venue address be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_venue_phone',
        'Display Venue Phone',
        'artistpress_display_venue_phone_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the venue phone number be displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'display_venue_website_button',
        'Venue Website Button',
        'artistpress_show_venue_web_button_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should there be a venue website button displayed on the individual show page.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field(
        'map_display',
        'Display Map',
        'artistpress_show_map_display_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should there be a map included on the show detail pages?'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field(
        'map_directions',
        'Provide Directions',
        'artistpress_show_map_directions_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should there be a way for site visitors to get directions to the venues?'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field(
        'artistpress_maps_api',
        'Google Maps API',
        'artistpress_show_map_api_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'A Google Maps API key is required. Visit our <a target="_blank" href="http://artistpress-plugin.com/documentation/">documentation</a> to learn how to get a API key.'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'show_use_stylesheet',
        'Show Default Stylesheet',
        'artistpress_show_stylesheet_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should the default show stylesheet be used to display the shows?'
        )
    );

    // Adds a setting field to Individual Shows settings section.
    add_settings_field( 
        'show_use_shortcode',
        'Use Shortcodes for Shows',
        'artistpress_show_shortcode_callback',
        'artistpress_show_settings', 
        'artistpress_show_settings_section',
        array(
            'Should shortcodes be used to display show details.'
        )
    );
    
    // Registers the Individual Shows settings section.
    register_setting(
        'artistpress_show_settings',
        'artistpress_show_settings',
        'artistpress_validate_input_examples'
    );
}
add_action('admin_init', 'artistpress_register_show_settings');





/**
 * Registers the ArtistPress Gallery settings
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */


function artistpress_register_gallery_settings(){
    
    // If the Artistpress Gallery options do not exist, create them using these defaults.
    if( false == get_option( 'artistpress_gallery_settings' ) ) {  
        $defaults = array(
                'gallery_behavior'                  => 'cardlightbox',
                'gallery_show_title'                => 'yes',
                'gallery_show_image_title'          => 'yes',
                'gallery_show_image_caption'        => 'yes',
                'gallery_use_gallery_stylesheet'    => 'yes'
        );
        add_option( 'artistpress_gallery_settings', $defaults);
    }

    // Adds the Gallery settings section.
    add_settings_section(
        'artistpress_gallery_settings_section',
        'Gallery Settings',
        'artistpress_gallery_settings_callback',
        'artistpress_gallery_settings'             
    );
    
    // Adds a setting field to Gallery settings section.
    add_settings_field( 
        'gallery_behavior',
        'Gallery Behavior',
        'artistpress_gallery_behavior_callback',
        'artistpress_gallery_settings',
        'artistpress_gallery_settings_section',
        array(
            'Choose the display style of your ArtistPress galleries.'
        )
    );

    // Adds a setting field to Gallery settings section.
    add_settings_field( 
        'gallery_show_title',
        'Gallery Title',
        'artistpress_gallery_title_callback',
        'artistpress_gallery_settings',
        'artistpress_gallery_settings_section',
        array(
            'Should the gallery name be displayed on the gallery page?'
        )
    );

    // Adds a setting field to Gallery settings section.
    add_settings_field( 
        'gallery_show_image_title',
        'Gallery Image Title',
        'artistpress_gallery_image_title_callback',
        'artistpress_gallery_settings',
        'artistpress_gallery_settings_section',
        array(
            'Should the image titles be displayed in the gallery?'
        )
    );

    // Adds a setting field to Gallery settings section.
    add_settings_field( 
        'gallery_show_image_caption',
        'Gallery Image Caption',
        'artistpress_gallery_image_caption_callback',
        'artistpress_gallery_settings',
        'artistpress_gallery_settings_section',
        array(
            'Should the image captions be displayed in the lightbox model window?'
        )
    );
    
    // Adds a setting field to Gallery settings section.
    add_settings_field( 
        'gallery_use_stylesheet',
        'Gallery Default Stylesheet',
        'artistpress_gallery_stylesheet_callback',
        'artistpress_gallery_settings',
        'artistpress_gallery_settings_section',
        array(
            'Should the default gallery stylesheet be used to display the galleries?'
        )
    );

    // Registers the Gallery settings section.
    register_setting(
        'artistpress_gallery_settings',
        'artistpress_gallery_settings',
        'artistpress_validate_input_examples'
    );
}
add_action('admin_init', 'artistpress_register_gallery_settings');



/**
 * Registers the ArtistPress Upgrade settings
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_register_upgrade_settings(){
    
    // If the Artistpress Upgrade tab options do not exist, create them using these defaults.
    if( false == get_option( 'artistpress_upgrade_settings' ) ) {  
        add_option( 'artistpress_upgrade_settings' );
    }

    // Adds the Upgrade settings section.
    add_settings_section(
        'artistpress_upgrade_settings_section',
        'Upgrade Settings',
        'artistpress_upgrade_settings_callback',
        'artistpress_upgrade_settings'    
    );

    // Registers the Upgrade settings section.
    register_setting(
        'artistpress_upgrade_settings',
        'artistpress_upgrade_settings',
        'artistpress_validate_input_examples'
    );
}
add_action('admin_init', 'artistpress_register_upgrade_settings');





/**
 * Returns the intro text for the Artist Settings tab
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */
function artistpress_artist_settings_callback() {
    echo '<p>These settings control the display of the ArtistPress Artists. These settings affect all artist shortcodes and artist page templates.</p>';
}

/**
 * Returns the intro text for the Show settings tab
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */
function artistpress_show_list_settings_callback() {
    echo '<p>These settings control the display of the ArtistPress Shows List.</p><p>The map settings for the shows are available on the <a href="?page=artistpress-settings&tab=show_settings">Individual Show Settings</a> tab.</p>';
}

/**
 * Returns the intro text for the Individual Show settings tab
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */
function artistpress_show_settings_callback(){
    echo '<p>These settings control the display of the ArtistPress Show Detail Pages.</p>';
}

/**
 * Returns the intro text for the Gallery settings tab
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */
function artistpress_gallery_settings_callback() {
    echo '<p>These settings control the display of the ArtistPress Galleries. These settings affect all album and gallery pages. This also includes shortcodes.</p>';
}

/**
 * Returns the intro text for the Upgrade settings tab
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */
function artistpress_upgrade_settings_callback() {
    echo '<p>Currently ArtistPress Pro and ArtistPress Community are being developed.</p><p>You can stay informed about progress and release dates on the <a href="https://www.facebook.com/ArtistPressPlugin" target="_blank">ArtistPress Facebook Page</a> or on the <a href="https://www.facebook.com/LetTimDesignIt" target="_blank">Let Tim Design It Facebook Page</a>.</p>';
}



/**
 * Renders the fields for the Artist settings section
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_artist_name_callback($args) {
    
    $options = get_option( 'artistpress_artist_settings' );
    
    if( ! isset($options['artist_name']) ) { $options['artist_name'] = false; }
    
    $html =  '<select id="artist_name" name="artistpress_artist_settings[artist_name]">';
    $html .= '<option value="yes"' . selected( $options['artist_name'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['artist_name'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="artist_name"> '  . $args[0] . '</label>';
     
    echo $html;
}

function artistpress_artist_phone_callback($args) {
    
    $options = get_option( 'artistpress_artist_settings' );
    
    if( ! isset($options['artist_phone']) ) { $options['artist_phone'] = false; }
    
    $html =  '<select id="artist_phone" name="artistpress_artist_settings[artist_phone]">';
    $html .= '<option value="yes"' . selected( $options['artist_phone'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['artist_phone'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="artist_phone"> '  . $args[0] . '</label>';
     
    echo $html;
}


function artistpress_artist_phoneLink_callback($args) {
    
    $options = get_option( 'artistpress_artist_settings' );
    
    if( ! isset($options['artist_phone_link']) ) { $options['artist_phone_link'] = false; }

    $html =  '<select id="artist_phone_link" name="artistpress_artist_settings[artist_phone_link]">';
    $html .= '<option value="yes"' . selected( $options['artist_phone_link'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['artist_phone_link'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="artist_phone_link"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_artist_email_callback($args) {

    $options = get_option( 'artistpress_artist_settings' );
    
    if( ! isset($options['artist_email']) ) { $options['artist_email'] = false; }

    $html =  '<select id="artist_email" name="artistpress_artist_settings[artist_email]">';
    $html .= '<option value="yes"' . selected( $options['artist_email'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['artist_email'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="artist_email"> '  . $args[0] . '</label>';
     
    echo $html;

}

function artistpress_artist_web_callback($args) {

    $options = get_option( 'artistpress_artist_settings' );
    
    if( ! isset($options['artist_web']) ) { $options['artist_web'] = false; }

    $html =  '<select id="artist_web" name="artistpress_artist_settings[artist_web]">';
    $html .= '<option value="yes"' . selected( $options['artist_web'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['artist_web'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="artist_web"> '  . $args[0] . '</label>';

    echo $html;

}

function artistpress_artist_bio_callback($args) {

    $options = get_option( 'artistpress_artist_settings' );
    
    if( ! isset($options['artist_bio']) ) { $options['artist_bio'] = false; }

    $html =  '<select id="artist_bio" name="artistpress_artist_settings[artist_bio]">';
    $html .= '<option value="yes"' . selected( $options['artist_bio'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['artist_bio'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="artist_bio"> '  . $args[0] . '</label>';

    echo $html;
}

function artistpress_artist_stylesheet_callback($args) {

    $options = get_option( 'artistpress_artist_settings' );
    
    if( ! isset($options['artist_use_artist_stylesheet']) ) { $options['artist_use_artist_stylesheet'] = false; }

    $html =  '<select id="artist_use_artist_stylesheet" name="artistpress_artist_settings[artist_use_artist_stylesheet]">';
    $html .= '<option value="yes"' . selected( $options['artist_use_artist_stylesheet'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['artist_use_artist_stylesheet'], 'no', false) . '>No</option>';
    $html .= '</select>';

    $html .= '<label for="artist_use_artist_stylesheet"> '  . $args[0] . '</label>';
     
    echo $html;
}

function artistpress_artist_shortcode_callback($args) {

    $options = get_option( 'artistpress_artist_settings' );
    
    if( ! isset($options['artist_use_artist_shortcode']) ) { $options['artist_use_artist_shortcode'] = false; }

    $html =  '<select id="artist_use_artist_shortcode" name="artistpress_artist_settings[artist_use_artist_shortcode]">';
    $html .= '<option value="yes"' . selected( $options['artist_use_artist_shortcode'], 'yes', false) . '>Use Shortcode</option>';
    $html .= '<option value="no"' . selected( $options['artist_use_artist_shortcode'], 'no', false) . '>Use Built-In Template</option>';
    $html .= '</select>';

    $html .= '<label for="artist_use_artist_shortcode"> '  . $args[0] . '</label>';
     
    echo $html;
}





/**
 * Renders the fields for the Show List settings section
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_show_list_display_callback($args) {

    $options = get_option( 'artistpress_show_list_settings' );
    if( ! isset($options['show_list_display']) ) { $options['show_list_display'] = false; }

    $html = '<select id="show_list_display" name="artistpress_show_list_settings[show_list_display]">';
        $html .= '<option value="default">Select a display option...</option>';
        $html .= '<option value="show_venue"' . selected( $options['show_list_display'], 'show_venue', false) . '>Order by Venue</option>';
        $html .= '<option value="show_date"' . selected( $options['show_list_display'], 'show_date', false) . '>Order by Date</option>';
        $html .= '<option value="show_artist"' . selected( $options['show_list_display'], 'show_artist', false) . '>Order by Artist</option>';
    $html .= '</select>';

    $html .= '<label for="show_list_display"> '  . $args[0] . '</label>';
    
    echo $html;

}

function artistpress_show_list_display_order($args) {

    $options = get_option( 'artistpress_show_list_settings' );
    if( ! isset($options['show_list_order']) ) { $options['show_list_order'] = false; }

    $html = '<select id="show_list_order" name="artistpress_show_list_settings[show_list_order]">';
        $html .= '<option value="default">Select a list order ...</option>';
        $html .= '<option value="ASC"' . selected( $options['show_list_order'], 'ASC', false) . '>Ascending</option>';
        $html .= '<option value="DESC"' . selected( $options['show_list_order'], 'DESC', false) . '>Descending</option>';
    $html .= '</select>';

    $html .= '<label for="show_list_order"> '  . $args[0] . '</label>';
    
    echo $html;

}

function artistpress_show_list_artist_callback($args) {

    $options = get_option( 'artistpress_show_list_settings' );
    if( ! isset($options['display_show_artist']) ) { $options['display_show_artist'] = false; }

    $html =  '<select id="display_show_artist" name="artistpress_show_list_settings[display_show_artist]">';
    $html .= '<option value="yes"' . selected( $options['display_show_artist'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['display_show_artist'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="display_show_artist"> '  . $args[0] . '</label>';
    
    echo $html;

}

function artistpress_show_list_venue_callback($args) {

    $options = get_option( 'artistpress_show_list_settings' );
    if( ! isset($options['display_show_venue']) ) { $options['display_show_venue'] = false; }

    $html =  '<select id="display_show_venue" name="artistpress_show_list_settings[display_show_venue]">';
    $html .= '<option value="yes"' . selected( $options['display_show_venue'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['display_show_venue'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="display_show_venue"> '  . $args[0] . '</label>';
    
    echo $html;
}

function artistpress_show_list_ticket_link_callback($args) {

    $options = get_option( 'artistpress_show_list_settings' );
    if( ! isset($options['display_ticket_button']) ) { $options['display_ticket_button'] = false; }

    $html =  '<select id="display_ticket_button" name="artistpress_show_list_settings[display_ticket_button]">';
    $html .= '<option value="yes"' . selected( $options['display_ticket_button'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['display_ticket_button'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="display_ticket_button"> '  . $args[0] . '</label>';

    echo $html;

}

function artistpress_show_list_ticket_link_label_callback($args) {

    $options = get_option( 'artistpress_show_list_settings' );
    if( ! isset($options['show_ticket_button_label']) ) { $options['show_ticket_button_label'] = false; }

    $html = '<input type="text" id="show_ticket_button_label" name="artistpress_show_list_settings[show_ticket_button_label]" value="'. $options[ 'show_ticket_button_label' ] .'" />';
    $html .= '<label for="show_ticket_button_label"> '  . $args[0] . '</label>';

    echo $html;

}

function artistpress_show_list_info_link_callback($args) {
    
    $options = get_option( 'artistpress_show_list_settings' );
    if( ! isset($options['display_info_button']) ) { $options['display_info_button'] = false; }

    $html =  '<select id="display_info_button" name="artistpress_show_list_settings[display_info_button]">';
    $html .= '<option value="yes"' . selected( $options['display_info_button'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['display_info_button'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="display_info_button"> '  . $args[0] . '</label>';

    echo $html;

}

function artistpress_show_list_info_link_label_callback($args) {

    $options = get_option( 'artistpress_show_list_settings' );
    if( ! isset($options['show_info_button_label']) ) { $options['show_info_button_label'] = false; }

    $html =  '<input type="text" id="show_info_button_label" name="artistpress_show_list_settings[show_info_button_label]" value="' . $options[ 'show_info_button_label' ] . '" />';
    $html .= '<label for="show_info_button_label"> '  . $args[0] . '</label>';

    echo $html;

}

function artistpress_show_list_stylesheet_callback($args) {

    $options = get_option( 'artistpress_show_list_settings' );
    
    if( ! isset($options['show_list_use_stylesheet']) ) { $options['show_list_use_stylesheet'] = false; }

    $html =  '<select id="show_list_use_stylesheet" name="artistpress_show_list_settings[show_list_use_stylesheet]">';
    $html .= '<option value="yes"' . selected( $options['show_list_use_stylesheet'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['show_list_use_stylesheet'], 'no', false) . '>No</option>';
    $html .= '</select>';

    $html .= '<label for="show_list_use_stylesheet"> '  . $args[0] . '</label>';
     
    echo $html;
}

function artistpress_show_list_shortcode_callback($args) {
    
    $options = get_option( 'artistpress_show_list_settings' );
    
    if( ! isset($options['show_list_use_shortcode']) ) { $options['show_list_use_shortcode'] = false; }

    $html =  '<select id="show_list_use_shortcode" name="artistpress_show_list_settings[show_list_use_shortcode]">';
    $html .= '<option value="yes"' . selected( $options['show_list_use_shortcode'], 'yes', false) . '>Use Shortcode</option>';
    $html .= '<option value="no"' . selected( $options['show_list_use_shortcode'], 'no', false) . '>Use Built-In Template</option>';
    $html .= '</select>';

    $html .= '<label for="show_list_use_shortcode"> '  . $args[0] . '</label>';
     
    echo $html;
}



/**
 * Renders the fields for the Individaul Shows settings section
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_display_show_artwork_callback($args) {
    
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_show_artwork']) ) { $options['display_show_artwork'] = false; }
    
    $html =  '<select id="display_show_artwork" name="artistpress_show_settings[display_show_artwork]">';
    $html .= '<option value="no"' . selected( $options['display_show_artwork'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_show_artwork'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_show_artwork"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_display_show_date_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_show_date']) ) { $options['display_show_date'] = false; }
    
    $html =  '<select id="display_show_date" name="artistpress_show_settings[display_show_date]">';
    $html .= '<option value="no"' . selected( $options['display_show_date'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_show_date'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_show_date"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_display_show_time_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_show_time']) ) { $options['display_show_time'] = false; }
    
    $html =  '<select id="display_show_time" name="artistpress_show_settings[display_show_time]">';
    $html .= '<option value="no"' . selected( $options['display_show_time'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_show_time'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_show_time"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_display_show_type_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_show_type']) ) { $options['display_show_type'] = false; }
    
    $html =  '<select id="display_show_type" name="artistpress_show_settings[display_show_type]">';
    $html .= '<option value="no"' . selected( $options['display_show_type'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_show_type'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_show_type"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_display_show_price_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_show_price']) ) { $options['display_show_price'] = false; }
    
    $html =  '<select id="display_show_price" name="artistpress_show_settings[display_show_price]">';
    $html .= '<option value="no"' . selected( $options['display_show_price'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_show_price'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_show_price"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_display_ticket_phone_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_ticket_phone']) ) { $options['display_ticket_phone'] = false; }
    
    $html =  '<select id="display_ticket_phone" name="artistpress_show_settings[display_ticket_phone]">';
    $html .= '<option value="no"' . selected( $options['display_ticket_phone'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_ticket_phone'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_ticket_phone"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_show_ticket_link_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_ticket_button']) ) { $options['display_ticket_button'] = false; }
    
    $html =  '<select id="display_ticket_button" name="artistpress_show_settings[display_ticket_button]">';
    $html .= '<option value="no"' . selected( $options['display_ticket_button'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_ticket_button'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_ticket_button"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_show_additional_info_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_additional_info']) ) { $options['display_additional_info'] = false; }
    
    $html =  '<select id="display_additional_info" name="artistpress_show_settings[display_additional_info]">';
    $html .= '<option value="no"' . selected( $options['display_additional_info'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_additional_info'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_additional_info"> '  . $args[0] . '</label>';
     
    echo $html;
}

function artistpress_display_venue_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_venue']) ) { $options['display_venue'] = false; }
    
    $html =  '<select id="display_venue" name="artistpress_show_settings[display_venue]">';
    $html .= '<option value="yes"' . selected( $options['display_venue'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['display_venue'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="display_venue"> '  . $args[0] . '</label>';
     
    echo $html;
}


function artistpress_display_venue_address_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_venue_address']) ) { $options['display_venue_address'] = false; }
    
    $html =  '<select id="display_venue_address" name="artistpress_show_settings[display_venue_address]">';
    $html .= '<option value="no"' . selected( $options['display_venue_address'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_venue_address'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_venue_address"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_display_venue_phone_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_venue_phone']) ) { $options['display_venue_phone'] = false; }
    
    $html =  '<select id="display_venue_phone" name="artistpress_show_settings[display_venue_phone]">';
    $html .= '<option value="no"' . selected( $options['display_venue_phone'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_venue_phone'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_venue_phone"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_show_venue_web_button_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['display_venue_website_button']) ) { $options['display_venue_website_button'] = false; }
    
    $html =  '<select id="display_venue_website_button" name="artistpress_show_settings[display_venue_website_button]">';
    $html .= '<option value="no"' . selected( $options['display_venue_website_button'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['display_venue_website_button'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="display_venue_website_button"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_show_map_display_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['map_display']) ) { $options['map_display'] = false; }
    
    $html =  '<select id="map_display" name="artistpress_show_settings[map_display]">';
    $html .= '<option value="no"' . selected( $options['map_display'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['map_display'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="map_display"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_show_map_directions_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['map_directions']) ) { $options['map_directions'] = false; }
    
    $html =  '<select id="map_directions" name="artistpress_show_settings[map_directions]">';
    $html .= '<option value="no"' . selected( $options['map_directions'], 'no', false) . '>No</option>';
    $html .= '<option value="yes"' . selected( $options['map_directions'], 'yes', false) . '>Yes</option>';
    $html .= '</select>';
    $html .= '<label for="map_directions"> '  . $args[0] . '</label>';
     
    echo $html;
}
function artistpress_show_map_api_callback($args) {
    $options = get_option( 'artistpress_show_settings' );
        
    if( ! isset($options['artistpress_maps_api']) ) { $options['artistpress_maps_api'] = false; }
        $html = '<input type="text" id="artistpress_maps_api" name="artistpress_show_settings[artistpress_maps_api]" value="'. $options[ 'artistpress_maps_api' ] .'" />';
        $html .= '<label for="artistpress_maps_api"> '  . $args[0] . '</label>';
    echo $html;
}
function artistpress_show_stylesheet_callback($args) {

    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['show_use_stylesheet']) ) { $options['show_use_stylesheet'] = false; }

    $html =  '<select id="show_use_stylesheet" name="artistpress_show_settings[show_use_stylesheet]">';
    $html .= '<option value="yes"' . selected( $options['show_use_stylesheet'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['show_use_stylesheet'], 'no', false) . '>No</option>';
    $html .= '</select>';

    $html .= '<label for="show_use_stylesheet"> '  . $args[0] . '</label>';
     
    echo $html;
}



function artistpress_show_shortcode_callback($args) {
    
    $options = get_option( 'artistpress_show_settings' );
    
    if( ! isset($options['show_use_shortcode']) ) { $options['show_use_shortcode'] = false; }

    $html =  '<select id="show_use_shortcode" name="artistpress_show_settings[show_use_shortcode]">';
    $html .= '<option value="no"' . selected( $options['show_use_shortcode'], 'no', false) . '>Only Use Templates</option>';
    $html .= '<option value="yes"' . selected( $options['show_use_shortcode'], 'yes', false) . '>Use Shortcode</option>';
    $html .= '</select>';

    $html .= '<label for="show_use_shortcode"> '  . $args[0] . '</label>';
     
    echo $html;
}



/**
 * Renders the fields for the Gallery settings section
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_gallery_behavior_callback($args) {
    
    $options = get_option( 'artistpress_gallery_settings' );
    if( ! isset($options['gallery_behavior']) ) { $options['gallery_behavior'] = false; }

    $html = '<select id="gallery_behavior" name="artistpress_gallery_settings[gallery_behavior]">';
    $html .= '<option value="cardlightbox">Card Lightbox</option>';
    // $html .= '<option value="filmstrip"' . selected( $options['gallery_behavior'], 'filmstrip', false) . '>Filmstrip</option>';
    $html .= '<option value="masonrylightbox"' . selected( $options['gallery_behavior'], 'masonrylightbox', false) . '>Masonry Lightbox</option>';
    $html .= '</select>';

    $html .= '<label for="gallery_behavior"> '  . $args[0] . '</label>';
    
    echo $html;
}

function artistpress_gallery_title_callback($args) {
    
    $options = get_option( 'artistpress_gallery_settings' );
    if( ! isset($options['gallery_show_title']) ) { $options['gallery_show_title'] = false; }

    $html =  '<select id="gallery_show_title" name="artistpress_gallery_settings[gallery_show_title]">';
    $html .= '<option value="yes"' . selected( $options['gallery_show_title'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['gallery_show_title'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="gallery_show_title"> '  . $args[0] . '</label>';
    
    echo $html;
}
function artistpress_gallery_image_title_callback($args) {

    $options = get_option( 'artistpress_gallery_settings' );
    if( ! isset($options['gallery_show_image_title']) ) { $options['gallery_show_image_title'] = false; }

    $html =  '<select id="gallery_show_image_title" name="artistpress_gallery_settings[gallery_show_image_title]">';
    $html .= '<option value="yes"' . selected( $options['gallery_show_image_title'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['gallery_show_image_title'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="gallery_show_image_title"> '  . $args[0] . '</label>';

    echo $html;
}
function artistpress_gallery_image_caption_callback($args) {

    $options = get_option( 'artistpress_gallery_settings' );
    if( ! isset($options['gallery_show_image_caption']) ) { $options['gallery_show_image_caption'] = false; }

    $html =  '<select id="gallery_show_image_caption" name="artistpress_gallery_settings[gallery_show_image_caption]">';
    $html .= '<option value="yes"' . selected( $options['gallery_show_image_caption'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['gallery_show_image_caption'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="gallery_show_image_caption"> '  . $args[0] . '</label>';

    echo $html;
}
function artistpress_gallery_stylesheet_callback($args) {

    $options = get_option( 'artistpress_gallery_settings' );
    if( ! isset($options['gallery_use_gallery_stylesheet']) ) { $options['gallery_use_gallery_stylesheet'] = false; }

    $html =  '<select id="gallery_use_gallery_stylesheet" name="artistpress_gallery_settings[gallery_use_gallery_stylesheet]">';
    $html .= '<option value="yes"' . selected( $options['gallery_use_gallery_stylesheet'], 'yes', false) . '>Yes</option>';
    $html .= '<option value="no"' . selected( $options['gallery_use_gallery_stylesheet'], 'no', false) . '>No</option>';
    $html .= '</select>';
    $html .= '<label for="gallery_use_gallery_stylesheet"> '  . $args[0] . '</label>';

    echo $html;
}



/**
 * Renders the fields for the Upgrade settings section
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

// There are no feilds for this section. It is advert to let users 
// know about the benefits of upgrading 


/**
 * Sanitization and Validation of all feild entries
 *
 * @author      LTDI Studios
 * @since       1.0.0
 *
 */

function artistpress_validate_input_examples( $input ) {
    
    // Create our array for storing the validated options
    $output = array();
    
    // Loop through each of the incoming options
    foreach( $input as $key => $value ) {
        
        // Check to see if the current option has a value. If so, process it.
        if( isset( $input[$key] ) ) {
         
            // Strip all HTML and PHP tags and properly handle quoted strings
            $output[$key] = strip_tags( stripslashes( $input[ $key ] ) );
             
        } // end if
         
    } // end foreach
     
    // Return the array processing any additional functions filtered by this action
    return apply_filters( 'artistpress_validate_input_examples', $output, $input );
 
} // end artistpress_validate_input_examples